﻿using LiveCharts;
using LiveCharts.Configurations;
using LiveCharts.Helpers;
using LiveCharts.Wpf;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UXCountryWorld
{
    public partial class CountryPC : Form
    {
        public CountryPC()
        {
            InitializeComponent();

            var mapper = Mappers.Xy<Population>()
                .X((population, index) => index)
                .Y(population => population.CountryPopulation);

            var records = PopulationCountryData.Countries.OrderByDescending(x => x.CountryPopulation).Take(5).ToArray();

            Results = records.AsChartValues();
            Labels = records.Select(x => x.Name).ToList();

            cartesianChartCP.Series = new SeriesCollection
            {
                new ColumnSeries
                {
                    Configuration = mapper,
                    Values = Results
                }
            };

            cartesianChartCP.AxisY.Add(new Axis
            {
                LabelFormatter = value => (value / 1000000).ToString("N") + "M"
            });
            cartesianChartCP.AxisX.Add(new Axis
            {
                Labels = Labels,
                DisableAnimations = true,
                LabelsRotation = 20,
                Separator = new Separator
                {
                    Step = 1
                }
            });
        }

        public ChartValues<Population> Results { get; set; }
        public List<string> Labels { get; set; }

        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            var newValue = ((TextBox)sender).Text ?? string.Empty;
            newValue = newValue.ToUpper();

            var records = PopulationCountryData.Countries
                .Where(x => x.Name.ToUpper().Contains(newValue))
                .OrderByDescending(x => x.CountryPopulation)
                .Take(5)
                .ToArray();

            Results.Clear();
            Results.AddRange(records);

            Labels.Clear();
            foreach (var record in records) Labels.Add(record.Name);
        }
    }
}
